@@ -8,12 +8,15 @@ Created on Sun Sep 20 21:55:20 2020
 import pyvisa
 import time
 import numpy as np
+
 rm = pyvisa.ResourceManager()
+name = "PowerMeter"
+
 
 class PowerMeter:
-    def __init__(self):
+    def __init__(self,port):
 
-        self.Pmeter = rm.open_resource('ASRL/dev/ttyUSB1::INSTR')
+        self.Pmeter = rm.open_resource(f'ASRL/{port.name}::INSTR')
 
     def Power(self):
         """Reads power from Gentec TPM300 via VISA commands
@@ -23,23 +26,20 @@ class PowerMeter:
         to-do: incorporate different power ranges (itteratively check all avaliable
         ranges and chose the best fit. Log this choice)"""
 
-
         while True:
             try:
                 Pread = self.Pmeter.query("*READPOWER:")
                 PowerPM = float(Pread.split('e')[0].split('+')[1])
                 return PowerPM
             except:
-                 continue
+                continue
 
     def PowAvg(self):
         P = []
-        for i in range(0,5,1):
+        for i in range(0, 5, 1):
             p = self.Power()
             P.append(p)
             time.sleep(1)
         PowerAvg = np.mean(P)
         PowerStd = np.std(P)
         return PowerAvg, PowerStd
-if __name__ == "__main__":
-    PowerMeter = PowerMeter()
