@@ -27,6 +27,8 @@ class InstrumentWrapper(param.Parameterized):
         self.hwids = [self.modules[i]["hwid"] for i in self.modules]
         self.reload_devices()
         self.button.on_click(self.reload_devices)
+        if "software_software" in self.devices.keys():
+            self.instrument_selected = "software_software"
 
     def reload_devices(self, event=None, debug=False):
         ports = find_ports()
@@ -37,7 +39,7 @@ class InstrumentWrapper(param.Parameterized):
                 if hwid == "software":
                     name = self.modules[module]["name"]
                     self.devices[f"software_{name}"] = {"name": name, "hwid": "software", "serial_number": "software",
-                                                        "module": module,"port":"software"}
+                                                        "module": module, "port": "software"}
                 else:
                     for port in ports:
                         if debug == True:
@@ -46,7 +48,7 @@ class InstrumentWrapper(param.Parameterized):
                         if str(hwid) == port.hwid.split(" ")[1].replace("VID:PID=", ""):
                             name = f"{port.serial_number} - {port.name} - {mname}"
                             self.devices[name] = {"name": port.name, "hwid": port.hwid,
-                                                  "serial_number": port.serial_number, "module": module,"port":port}
+                                                  "serial_number": port.serial_number, "module": module, "port": port}
         self.param["instrument_selected"].objects = self.devices.keys()
 
     @param.depends("instrument_selected", watch=True)
